@@ -10,8 +10,8 @@ class AlertManager(Manager): pass
 
 class PendingAlertManager(AlertManager):
     
-    def get_queryset(self, *args, **kwargs):
-        qs = super(PendingAlertManager, self).get_queryset(*args, **kwargs)
+    def get_query_set(self, *args, **kwargs):
+        qs = super(PendingAlertManager, self).get_query_set(*args, **kwargs)
         return qs.filter(is_sent=False, failed=False, when__gte=datetime.now())
     
     
